#!/usr/bin/perl -w -I../lib/
use strict;
use Remote::Use config => 'rsyncconfigweb';
use Trivial;

Trivial::hello();
